$eolcom #
$offlisting
$offsymlist
$offsymxref # onsymxref needs onlisting. Who knows why?
$offuellist
$offuelxref
option limrow=0, limcol=0; # Equation Listing and Column Listing are disabled
option solprint=off; # any printing from a solver is /turned off


$ontext
        "BALTIC SEA REDUCED NITROGEN COST MINIMIZING MODEL"
Author:
  Ing-Marie Gren, The Beijer Internationel Institute of Ecological Economics,
          Royal Swedish Academy of Sciences (RSAS), Stockholm, and
          Swedish University of Agricultural Sciences (SUAS), Uppsala
          Ing-Marie.Gren@ekon.slu.se
Adaptation for MARE:
  Alexander Sokolov, Stockholm University
          sokolov@system.ecology.su.se
$offtext

set  I  Emitting regions
    /DENKA     "Denmark Kattegat",
     DENSO     "Denmark Sounds",
     FIBB      "Finland Bothnian Bay",
     FIBS      "Finland Bothnian Sea",
     FIFV      "Finland Gulf of Finland",
     GERMANY   "Germany",
     VIST      "Poland Vistula",
     ODER      "Poland Oder",
     POLCOS    "Poland Coast",
     SEBB      "Sweden Bothnian Bay",
     SEBS      "Sweden Bothnian Sea",
     SEBAP     "Sweden Baltic Proper South",
     SEBANO    "Sweden Baltic Proper North",
     SESO      "Sweden Sounds",
     SEKA      "Sweden Kattegat",
     ESTOB     "Estonia Baltic Proper",
     ESTOG     "Estonia Gulf of Riga",
     ESTOF     "Estonia Gulf of Finland",
     LATVIB    "Latvia Baltic Proper",
     LATVIG    "Latvia Gulf of Riga",
     LITHUANIA "Lithuania",
     SUKAL     "Russia Baltic Proper",
     SUPET     "Russia Gulf of Finland"/;
set  M    LIVESTOCK                /CATTLE, PIGS, POULTRY/;
set  P    POPULATION               /INLURB, RURAL/;
set  T    LOADS                    /RIVER, DIRSEW, DIRIND/;
set  L    LAND ABATEMENT MEASURES  /CATCHC, ENERGYF, LEYGRAS/;
set  A    LAND COVER               /ARABLE, LEY, WETLAND/;
set  N    NUTRIENTS                /NITROGEN, PHOSPHORUS/;
set  H    NOx MEASURES             /SHIP, CAR, STATION/;
set  SeaRegions
  /BB "Bothnian Bay",
   BS "Bothnian Sea",
   BP "Baltic Proper",
   GF "Gulf of Finland",
   GR "Gulf of Riga",
   DS "Danish Straits",
   KT "Kattegat"/;
set  RegionAreas(SeaRegions,I)     /BB.(FIBB, SEBB),
                                    BS.(FIBS, SEBS),
                                    BP.(VIST, ODER, POLCOS,
                                        SEBAP, SEBANO, LITHUANIA,
                                        SUKAL, LATVIB, ESTOB),
                                    GF.(FIFV, SUPET, ESTOF),
                                    GR.(ESTOG, LATVIG),
                                    DS.(DENSO, SESO, GERMANY),
                                    KT.(DENKA, SEKA)/;
set Countries
  /SE "Sweden",
   FI "Finland",
   RU "Russia",
   EE "Estonia",
   LV "Latvia",
   LT "Lithuania",
   PL "Poland",
   DE "Germany",
   DK "Denmark"/;
set CountryAreas(Countries,I)  /SE.(SEBB,SEBS,SEBAP,SEBANO,SESO,SEKA),
                                FI.(FIBB,FIBS,FIFV),
                                RU.(SUPET,SUKAL),
                                EE.(ESTOF,ESTOG,ESTOB),
                                LV.(LATVIB,LATVIG),
                                LT.(LITHUANIA),
                                PL.(VIST,ODER,POLCOS),
                                DE.(GERMANY),
                                DK.(DENSO,DENKA)/;
set measures "list of measures, controlled by the Nest"
  /Wetland       "Wetland restoration",
   Fertilizer    "Fertilizer use",
   NOx           "NOx reduction",
   Sewage        "Sewage reduction",
   LandUse       "Land use",
   Livestock     "Livestock reduction",
   SpreadingTime "Change of N spreading time"/;

set dirSkagFlow
  /toKT      "flow from Skagerrak to Kattegat",
   fromKT    "flow fromKattegat to Skagerrak"/;

alias(SeaRegions,allRegions, sea_i, sea_j, sea_k);
alias (N, nutrient);


#***ATTANTION:_Do not modify this line! All following parameters and tables
#*** will be replased by the Nest!
#***
#*** All tables with price information MUST have word "price" as a substring 
#*** in the identificator!
#***
#***
#NEST_BEGIN

scalar LeakageReductionCoeff "LEAKAGE REDUCTION OF LAND USE CHANGES" /0.5/;
scalar inln_coeff                   /0.00438/;
scalar inlp_coeff                   /0.000913/;
scalar toalag_coeff                 /0.4/;

parameter atomicWeight(nutrient)  # It is used in calculation of transport matrices
/ NITROGEN   14.0,
  PHOSPHORUS 31.0
/;

#******* Expert's estimations. Compiled by Oleg Savchuk ******

parameter skagerFlow(dirSkagFlow)  # It is used in calculation of transport matrices
/ toKT    1814.100,
  fromKT  2372.898
/;

#  KT 401025.0   35992.0
;

table flow_old(sea_i ,sea_j)   # from j to i
         BB      BS       BP       GF      GR      DS       KT
  BB     0       173.133  0        0       0       0        0
  BS     289.577 0        1009.336 0       0       0        0
  BP     0       1237.193 0        554.043 171.191 840.711  0
  GF     0       0        435.262  0       0       0        0
  GR     0       0        133.442  0       0       0        0
  DS     0       0        1355.647 0       0       0        687.025
  KT     0       0        0        0       0       1211.856 0
;


table flow(sea_i ,sea_j)   # from i to j
         BB      BS       BP       GF      GR      DS       KT
  BB     0       289.577  0        0       0       0        0
  BS     173.133 0        1237.193 0       0       0        0
  BP     0       1009.336 0        435.262 133.442 1355.647 0
  GF     0       0        554.043  0       0       0        0
  GR     0       0        171.191  0       0       0        0
  DS     0       0        840.711  0       0       0        1211.856
  KT     0       0        0        0       0       687.025  0
;


table NutrientConcentration(SeaRegions,nutrient)  # It is used in calculation of transport matrices
       NITROGEN  PHOSPHORUS
  BB   21.43     0.23
  BS   19.35     0.45
  BP   21.53     1.04
  GF   25.57     0.74
  GR   35.08     0.97
  DS   21.53     0.89
  KT   18.14     0.72
;

parameter skagerConcentration(nutrient)  # It is used in calculation of transport matrices
/ NITROGEN   15.79,
  PHOSPHORUS 0.64
/;

#*************************************************

parameter PNmanureRelation(M) "RELATION PHOSPOROUS NITROGEN IN MANURE"
    /CATTLE 0.1538, PIGS 0.25, POULTRY 0.2727/;
parameter AmoniaTransportCoef(I) "TRANSPORT COEFFICIENTS FOR AMMONIUM FROM REGIONS DIRECT TO BAL"
    /DENKA     0.1437,
     DENSO     0.1437,
     FIBB      0.0297,
     FIBS      0.0297,
     FIFV      0.0297,
     GERMANY   0.0414,
     VIST      0.0435,
     ODER      0.0435,
     POLCOS    0.0435,
     SEBB      0.11,
     SEBS      0.11,
     SEBAP     0.11,
     SEBANO    0.11,
     SESO      0.11,
     SEKA      0.11,
     ESTOB     0.0313,
     ESTOG     0.047,
     ESTOF     0.078,
     LATVIB    0.05,
     LATVIG    0.0622,
     LITHUANIA 0.07,
     SUKAL     0.0162,
     SUPET     0.0162/;
     
parameter  NOxTransportCoef(I) "TRANSPORT COEFF NOx FROM DRAINBA J TO BAL"
    /DENKA     0.1490,
     DENSO     0.1490,
     FIBB      0.0343,
     FIBS      0.0343,
     FIFV      0.0343,
     GERMANY   0.0551,
     VIST      0.0573,
     ODER      0.0573,
     POLCOS    0.0573,
     SEBB      0.11,
     SEBS      0.11,
     SEBAP     0.11,
     SEBANO    0.11,
     SESO      0.11,
     SEKA      0.11,
     ESTOB     0.04,
     ESTOG     0.06,
     ESTOF     0.0956,
     LATVIB    0.08,
     LATVIG    0.0836,
     LITHUANIA 0.09,
     SUKAL     0.0207,
     SUPET     0.0207/;
     
parameter  ShareAmmoniaEmission(I) "SHARE OF AMMON EMISSION DEPOSITED ON OWN LAND"
    /DENKA     0.4254,
     DENSO     0.4254,
     FIBB      0.5187,
     FIBS      0.5187,
     FIFV      0.5187,
     GERMANY   0.584,
     VIST      0.595,
     ODER      0.595,
     POLCOS    0.595,
     SEBB      0.5679,
     SEBS      0.5679,
     SEBAP     0.5679,
     SEBANO    0.5679,
     SESO      0.5679,
     SEKA      0.5679,
     ESTOB     0.09,
     ESTOG     0.13,
     ESTOF     0.22,
     LATVIB    0.20,
     LATVIG    0.2588,
     LITHUANIA 0.5003,
     SUKAL     0.4115,
     SUPET     0.4115/;
parameter  ShareNOxEmission(I) "SHARE OF NOx EMISSION DEPOSITED ON OWN LAND"
    /DENKA     0.0318,
     DENSO     0.0318,
     FIBB      0.2071,
     FIBS      0.2071,
     FIFV      0.2071,
     GERMANY   0.1914,
     VIST      0.1909,
     ODER      0.1909,
     POLCOS    0.1909,
     SEBB      0.1977,
     SEBS      0.1977,
     SEBAP     0.1977,
     SEBANO    0.1977,
     SESO      0.1977,
     SEKA      0.1977,
     ESTOG     0.0467,
     ESTOB     0.0467,
     ESTOF     0.0467,
     LATVIB    0.0849,
     LATVIG    0.0849,
     LITHUANIA 0.0737,
     SUKAL     0.1303,
     SUPET     0.1303/;
parameter  NOxCoalEmission(I) "NOx EMISSIONS OF COAL THOUSAND TONS N"
    /DENKA     6,
     DENSO    11,
     FIBB      3,
     FIBS      4,
     FIFV      2.1,
     GERMANY  20,
     VIST     57,
     ODER     80,
     POLCOS    8,
     SEBB      0.44,
     SEBS      1.53,
     SEBAP     0.4,
     SEBANO    1.2,
     SESO      0.4,
     SEKA      1,
     ESTOB     0.4,
     ESTOG     0.6,
     ESTOF     1,
     LATVIB    1,
     LATVIG    1,
     LITHUANIA 3,
     SUKAL     5.5,
     SUPET    57/;
parameter  NOxOilEmission(I) "NOx EMISSIONS OF OIL THOUSAND TONS"
    /DENKA     2,
     DENSO     5,
     FIBB      5,
     FIBS      3,
     FIFV      3.2,
     GERMANY   6,
     VIST      7.8,
     ODER     11,
     POLCOS    1.2,
     SEBB      1.32,
     SEBS      4.8,
     SEBAP     0.9,
     SEBANO    4.2,
     SESO      0.9,
     SEKA      2.0,
     ESTOB     0.8,
     ESTOG     1.2,
     ESTOF     2,
     LATVIB    2,
     LATVIG    2,
     LITHUANIA 6.4,
     SUKAL    11,
     SUPET    12/;
parameter  NOxGasDieselEmission(I) "NOx EMISSIONS OF GAS AND DIESEL THOUSAND TONS"
    /DENKA    12,
     DENSO    28,
     FIBB     11,
     FIBS     15,
     FIFV      8,
     GERMANY  30,
     VIST     29,
     ODER     41,
     POLCOS    5,
     SEBB      5,
     SEBS     19,
     SEBAP     3.7,
     SEBANO   17,
     SESO      3.7,
     SEKA      9.7,
     ESTOB     0.6,
     ESTOG     0.9,
     ESTOF     1.5,
     LATVIB    1.5,
     LATVIG    1.5,
     LITHUANIA 4.6,
     SUKAL     1.7,
     SUPET     15/;
parameter  ShareManureBareGround(I) "PERC OF MAN APPLIED IN AUTUMN WINTER ON BARE GROUND"
    /DENKA     0.043,
     DENSO     0.043,
     FIBB      0.0604,
     FIBS      0.0604,
     FIFV      0.0604,
     GERMANY   0.0604,
     VIST      0.1,
     ODER      0.1,
     POLCOS    0.1,
     SEBB      0.0604,
     SEBS      0.0604,
     SEBAP     0.0604,
     SEBANO    0.0604,
     SESO      0.0604,
     SEKA      0.0604,
     ESTOB     0.07,
     ESTOG     0.10,
     ESTOF     0.18,
     LATVIB    0.125,
     LATVIG    0.125,
     LITHUANIA 0.25,
     SUKAL     0.35,
     SUPET     0.3/;
parameter  TotalDrainageArea(I)  "TOTAL AREA OF DRAINAGE BASINS THOUSAND KM"
    /DENKA     15.83, 
     DENSO     15.280, 
     FIBB     146, 
     FIBS      45.300, 
     FIFV     107, 
     GERMANY   10.4,
     VIST     171.210, 
     ODER     124.260, 
     POLCOS    37.140, 
     SEBB     113.620, 
     SEBS     176.610,
     SEBAP     30.112,
     SEBANO    53.113, 
     SESO       2.885, 
     SEKA      63.700, 
     ESTOB      1.1, 
     ESTOG     17.6,
     ESTOF     26.400, 
     LATVIB    11.1, 
     LATVIG    53.5, 
     LITHUANIA 65.3, 
     SUKAL     15.0, 
     SUPET    276.1/;
     
parameter  WetRestoration(I) "wetland restoration (%) of current wetland area"
    /DENKA       30,
     DENSO       70,
     FIBB        10,
     FIBS        30,
     FIFV        50,
     GERMANY    100,
     VIST       100,
     ODER       100,
     POLCOS     100,
     SEBB        10,
     SEBS        20,
     SEBAP       70,
     SEBANO      70,
     SESO       100,
     SEKA       100,
     ESTOB       30,
     ESTOG       30,
     ESTOF       30,
     LATVIB     100,
     LATVIG     100,
     LITHUANIA  100,
     SUKAL      100,
     SUPET      100/;
# NUTRIENT TRANSPORTS
parameter  NFertilizer(I)  "NITROGEN FERTILIZER KG PER HA"
    /DENKA    106,
     DENSO    106,
     FIBB      86,
     FIBS      86,
     FIFV      86,
     GERMANY  107.5,
     VIST      46,
     ODER      46,
     POLCOS    46,
     SEBB      50,
     SEBS      42,
     SEBAP     74,
     SEBANO    77,
     SESO     110,
     SEKA      75,
     ESTOB     32,
     ESTOG     32,
     ESTOF     32,
     LATVIB    26,
     LATVIG    26,
     LITHUANIA 12,
     SUKAL     12,
     SUPET     12/;
parameter  FertRestriction(I)  "NUTRIENT FERTILIZER RESTRICTION"
    /DENKA     0.5,
     DENSO     0.5,
     FIBB      0.5,
     FIBS      0.5,
     FIFV      0.5,
     GERMANY   0.5,
     VIST      0.8,
     ODER      0.8,
     POLCOS    0.8,
     SEBB      0.5,
     SEBS      0.5,
     SEBAP     0.5,
     SEBANO    0.5,
     SESO      0.5,
     SEKA      0.5,
     ESTOB     0.9,
     ESTOG     0.9,
     ESTOF     0.9,
     LATVIB    0.9,
     LATVIG    0.9,
     LITHUANIA 0.9,
     SUKAL     0.9,
     SUPET     0.9/;
parameter  PFertilizer(I) "PHOSPPHORUS FERT PER HA"
    /DENKA     9,
     DENSO     9,
     FIBB     12,
     FIBS     12,
     FIFV     12,
     GERMANY  10.7,
     VIST      3,
     ODER      3,
     POLCOS    3,
     SEBB      9,
     SEBS      6,
     SEBAP    12,
     SEBANO    6,
     SESO     11,
     SEKA      9,
     ESTOB     5,
     ESTOG     5,
     ESTOF     5,
     LATVIB    4,
     LATVIG    4,
     LITHUANIA 2,
     SUKAL     4,
     SUPET     4/;
parameter  WetlandRetention(I) "RETENTION OF WETLANDS"
    /DENKA     50,
     DENSO     50,
     FIBB      10,
     FIBS      10,
     FIFV      10,
     GERMANY   50,
     VIST      50,
     ODER      50,
     POLCOS    50,
     SEBB      10,
     SEBS      10,
     SEBAP     30,
     SEBANO    30,
     SESO      30,
     SEKA      30,
     ESTOB     50,
     ESTOG     50,
     ESTOF     50,
     LATVIB    50,
     LATVIG    50,
     LITHUANIA 50,
     SUKAL     50,
     SUPET     30/;
parameter  ShareNLeaching(I) "SHARE LEACHING OF NITROGEN"
    /DENKA     0.095,
     DENSO     0.095,
     FIBB      0.162,
     FIBS      0.162,
     FIFV      0.162,
     GERMANY   0.16,
     VIST      0.229,
     ODER      0.229,
     POLCOS    0.229,
     SEBB      0.051,
     SEBS      0.085,
     SEBAP     0.164,
     SEBANO    0.136,
     SESO      0.276,
     SEKA      0.207,
     ESTOB     0.315,
     ESTOG     0.315,
     ESTOF     0.315,
     LATVIB    0.358,
     LATVIG    0.358,
     LITHUANIA 0.442,
     SUKAL     0.617,
     SUPET     0.550/;
parameter  SharePLeaching(I) "SHARE LEACHING OF PHOSPHORUS"
    /DENKA     0.010,
     DENSO     0.010,
     FIBB      0.028,
     FIBS      0.028,
     FIFV      0.028,
     GERMANY   0.014,
     VIST      0.067,
     ODER      0.067,
     POLCOS    0.067,
     SEBB      0.019,
     SEBS      0.025,
     SEBAP     0.013,
     SEBANO    0.032,
     SESO      0.016,
     SEKA      0.016,
     ESTOB     0.066,
     ESTOG     0.066,
     ESTOF     0.066,
     LATVIB    0.093,
     LATVIG    0.093,
     LITHUANIA 0.114,
     SUKAL     0.067,
     SUPET     0.036/;
table  DrainageRetention(I,N) "Per cent of Nutrient DRAINAGE BASIN RETENTION"
               NITROGEN PHOSPHORUS
     DENKA      50      3
     DENSO      50      3
     FIBB       23     25
     FIBS       27     20
     FIFV       50     20
     GERMANY    37     30
     VIST       60     60
     ODER       60     24
     POLCOS     30     20
     SEBB       23     40
     SEBS       27     40
     SEBAP      60     47
     SEBANO     60     45
     SESO       30      0
     SEKA       20     40
     ESTOB      22     70
     ESTOG      22     70
     ESTOF      22     70
     LATVIB     30     70
     LATVIG     30     70
     LITHUANIA  35     70
     SUKAL      37     70
     SUPET      50     70;

table  CoastalRetention(I,N) "Per cent of Nutrient COASTAL RETENTION"
               NITROGEN PHOSPHORUS
     DENKA       40       0
     DENSO       25       0
     FIBB         0       0
     FIBS        10      15
     FIFV        15      20
     GERMANY     10      10
     VIST         5      10
     ODER        20      20
     POLCOS       0       0
     SEBB         0       0
     SEBS         0       0
     SEBAP        5       4
     SEBANO      34      32
     SESO         0       0
     SEKA         0       0
     ESTOB        0       0
     ESTOG        0       0
     ESTOF        0       0
     LATVIB       0       0
     LATVIG       0       0
     LITHUANIA    0       0
     SUKAL       20      15
     SUPET       33      55;

#  COST OF MEASURES
# sek/eur=9.5871 http://quote.bloomberg.com 2001-10-31
parameter  PriceWetlandRestoration(I) "RESTORATION COST MILL EUR PER THOUSKM2 WETLAND"
    /DENKA     77.39566709,
     DENSO     77.39566709,
     FIBB      77.39566709,
     FIBS      77.39566709,
     FIFV      77.39566709,
     GERMANY   77.39566709,
     VIST      15.75033117,
     ODER      15.75033117,
     POLCOS    15.75033117,
     SEBB      77.39566709,
     SEBS      77.39566709,
     SEBAP     77.39566709,
     SEBANO    77.39566709,
     SESO      77.39566709,
     SEKA      77.39566709,
     ESTOB     15.75033117,
     ESTOG     15.75033117,
     ESTOF     15.75033117,
     LATVIB    15.75033117,
     LATVIG    15.75033117,
     LITHUANIA 15.75033117,
     SUKAL     15.75033117,
     SUPET     15.75033117/;
parameter  NSewageCleaningRestriction(I) "RESTRICTION ON SEWAGE N CLEANING"
    /DENKA     0.4,
     DENSO     0.4,
     FIBB      0.4,
     FIBS      0.4,
     FIFV      0.4,
     GERMANY   0.5,
     VIST      0.6,
     ODER      0.6,
     POLCOS    0.6,
     SEBB      0.3,
     SEBS      0.3,
     SEBAP     0.3,
     SEBANO    0.3,
     SESO      0.3,
     SEKA      0.3,
     ESTOB     0.6,
     ESTOG     0.6,
     ESTOF     0.6,
     LATVIB    0.6,
     LATVIG    0.6,
     LITHUANIA 0.6,
     SUKAL     0.6,
     SUPET     0.6/;
parameter  PSewageCleaningRestriction(I) "RESTRICTION ON SEWAGE P CLEANING"
    /DENKA      0.2,
     DENSO      0.2,
     FIBB       0.2,
     FIBS       0.2,
     FIFV       0.2,
     GERMANY    0.5,
     VIST       0.6,
     ODER       0.6,
     POLCOS     0.6,
     SEBB       0.05,
     SEBS       0.05,
     SEBAP      0.05,
     SEBANO     0.05,
     SESO       0.05,
     SEKA       0.05,
     ESTOB      0.6,
     ESTOG      0.6,
     ESTOF      0.6,
     LATVIB     0.6,
     LATVIG     0.6,
     LITHUANIA  0.6,
     SUKAL      0.6,
     SUPET      0.6/;
parameter  Transparency(SeaRegions) "It is used by Nest only"
   /BB   0.0,
    BS   0.0,
    BP   0.0,
    GF   0.0,
    GR   0.0,
    DS   0.0,
    KT   0.0/;
parameter  NflowPercentOfReduction(SeaRegions) "see equation NflowRestriction"
   /BB   0.0,
    BS   0.0,
    BP   0.0,
    GF   0.0,
    GR   0.0,
    DS   0.0,
    KT   0.0/;
parameter  NdrRestPercentOfReduction(SeaRegions)  "see equation"
   /BB  0.0,
    BS  0.0,
    BP  0.0,
    GF  0.0,
    GR  0.0,
    DS  0.0,
    KT  0.0/;
parameter  PflowPercentOfReduction(SeaRegions) "see equation "
   /BB   0.0,
    BS   0.0,
    BP   0.0,
    GF   0.0,
    GR   0.0,
    DS   0.0,
    KT   0.0/;
parameter  PdrRestPercentOfReduction(SeaRegions)  "see equation"
   /BB  0.0,
    BS  0.0,
    BP  0.0,
    GF  0.0,
    GR  0.0,
    DS  0.0,
    KT  0.0/;

table Livestock(I,M) "HOLDINGS OF LIVESTOCK IN MILLS"
                   CATTLE   PIGS      POULTRY
  DENKA            0.433    2.459     3.921
  DENSO            0.866    5.737     9.150
  FIBB             0.404    0.381     2.212
  FIBS             0.525    0.495     2.875
  FIFV             0.538    0.507     2.947
  GERMANY          1.415    1.432     0
  VIST             6.153   10.844    30.990
  ODER             3.301    5.818    16.627
  POLCOS           1.068    1.883     5.382
  SEBB             0.054    0.033     0.128
  SEBS             0.215    0.075     0.418
  SEBAP            0.485    0.626     2.610
  SEBANO           0.367    0.407     2.732
  SESO             0.067    0.206     0.960
  SEKA             0.536    0.933     3.540
  ESTOB            0.065    0.061     0.52
  ESTOG            0.1      0.091     0.78
  ESTOF            0.163    0.153     1.301
  LATVIB           0.200    0.200     1.7
  LATVIG           0.277    0.230     1.855
  LITHUANIA        1.068    1.205     7.447
  SUKAL            0.381    0.177     2.920
  SUPET            0.802    0.372     6.144;

table NperAnimal(I,M) "NITROGEN CONTENT IN KG PER ANIMAL"
                   CATTLE  PIGS    POULTRY
  DENKA            42.703  9.246   0.626
  DENSO            42.703  9.246   0.626
  FIBB             42.703  9.246   0.626
  FIBS             42.703  9.246   0.626
  FIFV             42.703  9.246   0.626
  GERMANY          42.703  9.246   0.626
  VIST             23.815  6.164   0.423
  ODER             23.815  6.164   0.423
  POLCOS           23.815  6.164   0.423
  SEBB             42.703  9.246   0.626
  SEBS             42.703  9.246   0.626
  SEBAP            42.703  9.246   0.626
  SEBANO           42.703  9.246   0.626
  SESO             42.703  9.246   0.626
  SEKA             42.703  9.246   0.626
  ESTOB            23.815  6.164   0.423
  ESTOG            23.815  6.164   0.423
  ESTOF            23.815  6.164   0.423
  LATVIB           23.815  6.164   0.423
  LATVIG           23.815  6.164   0.423
  LITHUANIA        23.815  6.164   0.423
  SUKAL            23.815  6.164   0.423
  SUPET            23.815  6.164   0.423;

table PperAnimal(I,M) "P CONTENT IN KG PER ANIMAL"
                   CATTLE  PIGS    POULTRY
  DENKA            6.590   2.495   0.150
  DENSO            6.590   2.495   0.150
  FIBB             6.590   2.495   0.150
  FIBS             6.590   2.495   0.150
  FIFV             6.590   2.495   0.150
  GERMANY          6.590   2.495   0.150
  VIST             3.675   1.663   0.101
  ODER             3.675   1.663   0.101
  POLCOS           3.675   1.663   0.101
  SEBB             6.590   2.495   0.150
  SEBS             6.590   2.495   0.150
  SEBAP            6.590   2.495   0.150
  SEBANO           6.590   2.495   0.150
  SESO             6.590   2.495   0.150
  SEKA             6.590   2.495   0.150
  ESTOB            3.675   1.663   0.101
  ESTOG            3.675   1.663   0.101
  ESTOF            3.675   1.663   0.101
  LATVIB           3.675   1.663   0.101
  LATVIG           3.675   1.663   0.101
  LITHUANIA        3.675   1.663   0.101
  SUKAL            3.675   1.663   0.101
  SUPET            3.675   1.663   0.101;

table Population(I,P) "POPULATION 1000S IN URBAN AND RURAL AREAS"
                    INLURB         RURAL
  DENKA                 0           169
  DENSO                 0           389
  FIBB                  0           261
  FIBS                  0           309
  FIFV                  0          1312
  GERMANY               0          2073
  VIST               2407         11289
  ODER               2061         18473
  POLCOS                0          2407
  SEBB                307            77
  SEBS                886           344
  SEBAP               716           234
  SEBANO             1498           318
  SESO                230            45
  SEKA               1201           390
  ESTOB               120            80
  ESTOG               180           120
  ESTOF               300           201
  LATVIB              160           117
  LATVIG              784           573
  LITHUANIA          2100          1200
  SUKAL               205           154
  SUPET               305          1067;

table NDrainageLoad(I,T) "KTONS OF N LOADS FROM DRAINAGE BASINS"
                   RIVER    DIRSEW   DIRIND
  DENKA            31.7     0.747    0.658
  DENSO            29.450   4.593    1.532
  FIBB             25.243   1.165    1.193
  FIBS             19.277   1.795    1.260
  FIFV             11.569   4.136    0.435
  GERMANY          10.234   4.189    0.043
  VIST             124.905  4.296    0.538
  ODER             79.272   1.926    0.238
  POLCOS           10.477   0        0
  SEBB             16.290   0.742    0.315
  SEBS             28.459   1.303    1.754
  SEBAP            18.686   1.244    0.683
  SEBANO           10.467   5.339    0.01
  SESO             5.536    1.362    0.2
  SEKA             35.330   2.981    1.171
  ESTOB            0.27     0.004    0.008
  ESTOG            9.00     0.106    0
  ESTOF            33.934   1.577    1.568
  LATVIB           13.498   0.237    0.112
  LATVIG           75.92    1.143    0.155
  LITHUANIA        35.631   0.896    0.296
  SUKAL            3.1      1.376    0.491
  SUPET            57.088   19.676   2.916;

table PDrainageLoad(I,T)  "KTONS OF P LOAD FROM DRAINAGE BASINS"
                   RIVER   DIRSEW  DIRIND
  DENKA            0.750   0.085   0.08
  DENSO            0.809   0.73    0.143
  FIBB             1.586   0.013   0.091
  FIBS             1.05    0.044   0.145
  FIFV             0.523   0.055   0.054
  GERMANY          0.3     0.079   0.003
  VIST             7.529   0.537   0.118
  ODER             5.744   0.247   0.050
  POLCOS           0.179      0       0
  SEBB             1.13    0.018   0.034
  SEBS             1.264   0.022   0.217
  SEBAP            0.409   0.019   0.069
  SEBANO           0.444   0.070      0
  SESO             0.109   0.031   0.005
  SEKA             0.744   0.119   0.013
  ESTOB            0.0     0.001   0.001
  ESTOG            0.24    0.018   0.000
  ESTOF            0.893   0.116   0.022
  LATVIB           0.232   0.026   0.020
  LATVIG           1.572   0.308   0.026
  LITHUANIA        1.270   0.119   0.016
  SUKAL            0.260   0.193   0.156
  SUPET            3.310   2.442   0.747;

# LAND COVER
table LandCover(I,A)  "LAND COVER IN THOUSAND SQRKM"
                   ARABLE    LEY   WETLAND
  DENKA            9.54     0.836  0.161
  DENSO            9.213    1.949  0.375
  FIBB             6.571    1.677  33.740
  FIBS             7.565    2.179  2.350
  FIFV             8.774    2.233  5.990
  GERMANY          6.126    0.959  0.576
  VIST             64.539   17.781 7.626
  ODER             41.627   9.540  4.125
  POLCOS           11.209   3.088  1.394
  SEBB             0.243    0.576  19.950
  SEBS             0.982    1.982  19.500
  SEBAP            2.739    2.261  1.604
  SEBANO           4.277    2.116  2.051
  SESO             1.339    0.271  0.517
  SEKA             3.854    3.058  2.128
  ESTOB            0.142    0.072  0.145
  ESTOG            5.68     2.32   4.03
  ESTOF            8.527    3.201  7.046
  LATVIB           4.324    1.112  0.98
  LATVIG           20.929   4.182  3.58
  LITHUANIA        23.698   11.151 2.555
  SUKAL            3.851    4.040  0.420
  SUPET            4.350    1.200  13.225;

# sek/eur=9.5871 http://quote.bloomberg.com 2001-10-31
table  PriceSewageReduction(I,N) "MILL EUR PER THOUSAND TON SEWAGE REDUCTION"
                  NITROGEN     PHOSPHORUS
     DENKA       5.00672779   10.11776241
     DENSO       5.00672779   10.11776241
     FIBB        5.00672779   10.11776241
     FIBS        5.00672779   10.11776241
     FIFV        5.00672779   10.11776241
     GERMANY     2.086136579  2.336472969
     VIST        0.938761461  2.336472969
     ODER        0.938761461  2.336472969
     POLCOS      0.938761461  2.336472969
     SEBB        5.00672779   4.902420962
     SEBS        5.00672779   4.902420962
     SEBAP       5.00672779   4.902420962
     SEBANO      5.00672779   4.902420962
     SESO        5.00672779   4.902420962
     SEKA        5.00672779   4.902420962
     ESTOB       0.938761461  2.336472969
     ESTOG       0.938761461  2.336472969
     ESTOF       0.938761461  2.336472969
     LATVIB      0.938761461  2.336472969
     LATVIG      0.938761461  2.336472969
     LITHUANIA   0.938761461  2.336472969
     SUKAL       0.938761461  2.336472969
     SUPET       0.938761461  2.336472969;

table PriceFertilizer(I,N) "NUTRIENT FERTILISER PRICES MILL EUR PER THOUSAND TON 1997"
                  NITROGEN        PHOSPHORUS
  DENKA           0.585682845     0.74767135
  DENSO           0.585682845     0.74767135
  FIBB            0.537597397     0.686234628
  FIBS            0.537597397     0.686234628
  FIFV            0.537597397     0.686234628
  GERMANY         0.523515975     0.568367911
  VIST            0.255656038     0.309478362
  ODER            0.255656038     0.309478362
  POLCOS          0.255656038     0.309478362
  SEBB            0.840504428     1.117126138
  SEBS            0.840504428     1.117126138
  SEBAP           0.840504428     1.117126138
  SEBANO          0.840504428     1.117126138
  SESO            0.840504428     1.117126138
  SEKA            0.840504428     1.117126138
  ESTOB           0.320013351     0.362466231
  ESTOG           0.320013351     0.362466231
  ESTOF           0.320013351     0.362466231
  LATVIB          0.320013351     0.362466231
  LATVIG          0.320013351     0.362466231
  LITHUANIA       0.320013351     0.362466231
  SUKAL           0.169289983     0.191715952
  SUPET           0.169289983     0.191715952;

table NPFertilizerElasticity(I,N) "NUTRIENT FERTILISER ABSOLUTE ELASTICITIES"
                 NITROGEN        PHOSPHORUS
  DENKA            0.64            0.27
  DENSO            0.64            0.27
  FIBB             0.57            0.22
  FIBS             0.39            0.23
  FIFV             0.36            0.2
  GERMANY          0.3             0.3
  VIST             0.3             0.3
  ODER             0.3             0.3
  POLCOS           0.3             0.3
  SEBB             0.74            0.99
  SEBS             0.64            0.47
  SEBAP            0.71            0.24
  SEBANO           0.71            0.24
  SESO             0.71            0.24
  SEKA             0.71            0.24
  ESTOB            0.3             0.3
  ESTOG            0.3             0.3
  ESTOF            0.3             0.3
  LATVIB           0.3             0.3
  LATVIG           0.3             0.3
  LITHUANIA        0.3             0.3
  SUKAL            0.3             0.3
  SUPET            0.3             0.3;

table PriceLivestockReduction(I,M) "LIVESTOCK RED COST MILL EUR PER MILL ST"
                 CATTLE      PIGS        POULTRY
  DENKA          516.9446444 66.9649842  3.233511698
  DENSO          516.9446444 66.9649842  3.233511698
  FIBB           714.6060853 61.85394958 4.798114133
  FIBS           723.5764726 57.57736959 4.485193646
  FIFV           658.5933181 56.42999447 3.546432185
  GERMANY        328.8794317 31.70927601 1.98182975
  VIST           101.4905446 8.031625831 0.521534145
  ODER           101.4905446 8.031625831 0.521534145
  POLCOS         101.4905446 8.031625831 0.521534145
  SEBB           714.6060853 61.85394958 4.798114133
  SEBS           723.5764726 57.57736959 4.485193646
  SEBAP          658.5933181 56.42999447 3.546432185
  SEBANO         619.5825641 52.25772131 4.276579988
  SESO           583.5967081 56.42999447 3.546432185
  SEKA           676.7427063 53.82232375 3.650739014
  ESTOB          101.4905446 8.031625831 0.521534145
  ESTOG          101.4905446 8.031625831 0.521534145
  ESTOF          101.4905446 8.031625831 0.521534145
  LATVIB         101.4905446 8.031625831 0.521534145
  LATVIG         101.4905446 8.031625831 0.521534145
  LITHUANIA      101.4905446 8.031625831 0.521534145
  SUKAL          101.4905446 8.031625831 0.521534145
  SUPET          101.4905446 8.031625831 0.521534145;

table PriceLandUse(I,L) "COSTS LAND USE MILL EUR PER THOUSAND SQRKM"
                 CATCHC     ENERGYF     LEYGRAS
  DENKA        9.387614607  55.7415694  29.62313943
  DENSO        9.387614607  55.7415694  29.62313943
  FIBB         9.387614607  44.14265002 0.020861366
  FIBS         9.387614607  44.67461485 0.020861366
  FIFV         9.387614607  55.44951028 9.39804529
  GERMANY      9.387614607  57.68167642 34.66115927
  VIST         9.387614607  6.915542761 4.151411793
  ODER         9.387614607  6.915542761 4.151411793
  POLCOS       9.387614607  6.915542761 4.151411793
  SEBB         9.387614607  44.14265002 0.020861366
  SEBS         9.387614607  44.67461485 0.020861366
  SEBAP        9.387614607  55.44951028 9.39804529
  SEBANO       9.387614607  53.6658635  7.572675783
  SESO         9.387614607  75.67460442 29.62313943
  SEKA         9.387614607  59.95556529 18.90039741
  ESTOB        9.387614607  6.915542761 4.151411793
  ESTOG        9.387614607  6.915542761 4.151411793
  ESTOF        9.387614607  6.915542761 4.151411793
  LATVIB       9.387614607  6.915542761 4.151411793
  LATVIG       9.387614607  6.915542761 4.151411793
  LITHUANIA    9.387614607  6.915542761 4.151411793
  SUKAL        9.387614607  6.915542761 4.151411793
  SUPET        9.387614607  6.915542761 4.151411793;

table PriceNOxReduction(I,H) "NOx RED COST MILL EUR PER KTON N"
                 SHIP         CAR         STATION
  DENKA       1.397711508  0.774999739  18.36843258
  DENSO       1.397711508  0.774999739  18.36843258
  FIBB        1.397711508  0.774999739  18.05551209
  FIBS        1.397711508  0.774999739  18.05551209
  FIFV        1.397711508  0.774999739  18.05551209
  GERMANY     1.397711508  0.774999739  18.87953604
  VIST        1.397711508  0.774999739  17.57570068
  ODER        1.397711508  0.774999739  17.57570068
  POLCOS      1.397711508  0.774999739  17.57570068
  SEBB        1.397711508  0.774999739  18.21197234
  SEBS        1.397711508  0.774999739  18.21197234
  SEBAP       1.397711508  0.774999739  18.21197234
  SEBANO      1.397711508  0.774999739  18.21197234
  SESO        1.397711508  0.774999739  18.21197234
  SEKA        1.397711508  0.774999739  18.21197234
  ESTOB       1.397711508  0.774999739  17.57570068
  ESTOG       1.397711508  0.774999739  17.57570068
  ESTOF       1.397711508  0.774999739  17.57570068
  LATVIB      1.397711508  0.774999739  17.57570068
  LATVIG      1.397711508  0.774999739  17.57570068
  LITHUANIA   1.397711508  0.774999739  17.57570068
  SUKAL       1.397711508  0.774999739  17.57570068
  SUPET       1.397711508  0.774999739  17.57570068;

table MeasuresControl(I,measures)
             Wetland  Fertilizer  NOx    Sewage   LandUse Livestock SpreadingTime
  DENKA          1.0      1.0     1.0      1.0     1.0      1.0        1.0
  DENSO          1.0      1.0     1.0      1.0     1.0      1.0        1.0
  FIBB           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  FIBS           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  FIFV           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  GERMANY        1.0      1.0     1.0      1.0     1.0      1.0        1.0
  VIST           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  ODER           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  POLCOS         1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SEBB           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SEBS           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SEBAP          1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SEBANO         1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SESO           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SEKA           1.0      1.0     1.0      1.0     1.0      1.0        1.0
  ESTOB          1.0      1.0     1.0      1.0     1.0      1.0        1.0
  ESTOG          1.0      1.0     1.0      1.0     1.0      1.0        1.0
  ESTOF          1.0      1.0     1.0      1.0     1.0      1.0        1.0
  LATVIB         1.0      1.0     1.0      1.0     1.0      1.0        1.0
  LATVIG         1.0      1.0     1.0      1.0     1.0      1.0        1.0
  LITHUANIA      1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SUKAL          1.0      1.0     1.0      1.0     1.0      1.0        1.0
  SUPET          1.0      1.0     1.0      1.0     1.0      1.0        1.0
;


#NEST_END Don't modify this line!


parameter  NRiverLoadCalibration(I); # "CALIBRATION OF RIVERINE  N LOADS"
  NRiverLoadCalibration(I)=1.0;      # it will be recalculated
parameter  PRiverLoadCalibration(I); # "CALIBRATION OF RIVERINE P LOADS"
  PRiverLoadCalibration(I)=1.0;      # it will be recalculated

parameter N_transport_coeff(SeaRegions,allRegions); #  see equation NflowRestriction
  N_transport_coeff(SeaRegions,allRegions)=0.0; # actual values are calculated in the first pass
parameter P_transport_coeff(SeaRegions,allRegions); # see equation PflowRestriction
  P_transport_coeff(SeaRegions,allRegions)=0.0; # actual values are calculated in the first pass

parameter  Nflow_max(SeaRegions); # "see equation NflowRestriction"
  Nflow_max(SeaRegions)=999999.9;

parameter  NfromLand_max(SeaRegions);  # "see equation"
  NfromLand_max(SeaRegions)=999999.9;

parameter  Pflow_max(SeaRegions); #  "see equation"
  Pflow_max(SeaRegions)=999999.9;

parameter  PfromLand_max(SeaRegions); # "see equation"
  PfromLand_max(SeaRegions)=999999.9;

parameter NLiveStock(I); # N FROM LIVESTOCK IN THOUSAND TON
  NLiveStock(I) = sum(M,(NperAnimal(I,M)*Livestock(I,M)));

parameter PLiveStock(I); # P FROM LIVESTOCK IN THOUSAND TON
  PLiveStock(I) = sum(M,(PperAnimal(I,M)*Livestock(I,M)));

parameter TotalNOxEmission(I); # TOTAL NOx EMISSIONS IN THOUSAND TON
  TotalNOxEmission(I) = NOxOilEmission(I)+NOxGasDieselEmission(I)+NOxCoalEmission(I);

parameter INLN(I); # INLAND NITROGEN SEWAGE IN THOUSAND TON
  INLN(I) = inln_coeff*(sum(P,Population(I,P)));

parameter INLP(I); # INLAND PHOSPORUS SEWAGE IN THOUSAND TON
  INLP(I) = inlp_coeff*(sum(P,Population(I,P)));

parameter DIRN(I); # DIRECT NITROGEN LOAD IN KTON TO BALTIC SEA
  DIRN(I) = NDrainageLoad(I,"DIRSEW")+NDrainageLoad(I,"DIRIND");

parameter DIRP(I); # DIRECT PHOSPHORUS LOAD IN KTON TO THE BALTIC SEA
  DIRP(I) = PDrainageLoad(I,"DIRSEW")+PDrainageLoad(I,"DIRIND");

parameter TotalArableArea(I); # TOTAL ARABLE LAND IN THOUSAND SQRKM
  TotalArableArea(I) = LandCover(I,"ARABLE")+LandCover(I,"LEY");

parameter ArableShare(I); # SHARE OF ARABLE LAND IN REGION OF COUNTRY
  ArableShare(I) = TotalArableArea(I)/TotalDrainageArea(I);

parameter TOALAG(I); # TOTAL LEACHING NOx AIR LOAD ON ARABLE LAND IN THOUSAND TON
  TOALAG(I) = ShareNLeaching(I)*ArableShare(I)*(TotalNOxEmission(I)*ShareNOxEmission(I)+
              toalag_coeff*NLiveStock(I)*ShareAmmoniaEmission(I));

parameter TOALO(I); # TOTAL LEACHING FROM AIR LOAD ON OTHER LAND IN THOUSAND TON;
  TOALO(I) = ShareNLeaching(I)*TOALAG(I)*(TotalDrainageArea(I)/TotalArableArea(I));

# added 2002-01-08
parameter NFERT(I); # NITROGEN FERTILIZER IN REGIONS IN THOUSAND TONS;
NFERT(I) = 0.1*NFertilizer(I)*TotalArableArea(I);  #added 2002-01-08

parameter PFERT(I); # PHOSPHORUS FERTILIZER IN REGIONS IN THOUSAND TONS;
PFERT(I) = 0.1*PFertilizer(I)*TotalArableArea(I);  #added 2002-01-08

parameter FNCOEFF(I); # COEFFICIENT IN INVERTED NITROGEN FERT DEMAND;
         FNCOEFF(I) = PriceFertilizer(I, "NITROGEN")/
         (2*NPFertilizerElasticity(I, "NITROGEN")*NFERT(I));  #added 2002-01-08

parameter FPCOEFF(I); # COEFFICIENT IN INVERTED PHSOPSOHROUS FERT DEMAND;
         FPCOEFF(I) = PriceFertilizer(I, "PHOSPHORUS")/
         (2*NPFertilizerElasticity(I, "PHOSPHORUS")*PFERT(I));  #added 2002-01-08

parameter INTERN(I); # INTERCEPT IN INVERTED NITROGEN FERT DEMAND;
         INTERN(I) = PriceFertilizer(I, "NITROGEN")+(FNCOEFF(I)*NFERT(I));  #added 2002-01-08

parameter INTERP(I); # INTERCEPT IN INVERTED PHOSPHORUS FERT DEMAND;
         INTERP(I) = PriceFertilizer(I, "PHOSPHORUS") + (FPCOEFF(I)*PFERT(I));  #added 2002-01-08

parameter CALIBFN(I); # CALIBRATION OF NFERT RED COST FUNCTIONS;
         CALIBFN(I) = ((INTERN(I)-PriceFertilizer(I, "NITROGEN"))*NFERT(I)/2)/TotalArableArea(I);

variables
     AmmoniaLiveStockReduction(I,M)  " AMMONIA LIVESTOCK REDUCTIONS"
     NFertilizerUse(I)   " N FERTILIZER USE"
     PFertilizerUse(I)   " P FERTILIZER USE"
     NOxReduction(I,H) " NOx REDUCTION MEASURES"
     AmmoniaLandEmission(I)    " AMMONIUM EMISSION IN DIFFERENT COUNTRIES"
     NOxEmission(I)    " NOx EMISSIONS AFTER ENG RED"
     NOxDeposition(I)    " NOx DEPOSITION ON BALTIC COUNTRIES"
     ArableAirDeposition(I)   " AIR DEPOSITION ON ARABLE LAND"
     AirToLand(I)    " AIR DEPOSITION ON OTHER LAND"
     AirToSea(I)  " AIR DEPOSITION ON BALTIC SEA"
     NSewageReduction(I)   " SEW N REDUCTIONS"
     NInlandSewageReduction(I)  " SEWAGE RED WATER STREAMS"
     PInlandSewageReduction(I)  " INLAND SEWAGE P REDUCTION"
     NSewageDirectLoad(I)  " SEWAGE DIRECT LOAD ON BALTIC"
     NLoadWetland(I) " NITROGEN LOAD ON WETLAND"
     PLoadWetland(I) " P LOAD ON WETLAND"
     WetlandRestoration(I)   " SQKM OF WETLAND RESTORATION"
     NWetlandReduction(I)  " NITROGEN REDUCTION FROM WETLANDS"
     PWetlandReduction(I)  " P REDUCTION FROM WETLANDS"
     NRegionToSea(I)  " N LOAD ON BALTIC SEA OF BALTIC COUNTRIES"
     PRegionToSea(I)    " TOTAL P LOAD FROM REGIONS"
     LandUseChanges(I,L) " LAND USE CHANGES IN KM"
     NLeakageLandUse(I,L) " LEAKAGE REDUCTION FROM LANDE USE CHANGE"
     TotalNLandLoad(I)    " TOTAL NITROGEN LOAD ON BALTIC COUNTRIES LAND"
     NfromLand(SeaRegions) " Nitrogen land transport"
     CostManureReduction(I)  " COSTS FOR MANURE REDUCTIONS"
     CostNOxReduction(I)  " COSTS FOR NOx REDUCTIONS"
     CostNSewageReduction(I)  " COSTS FOR N RED SEWAGE"
     NSpreadingTimeChange(I)   " CHANGE OF SPREADING TIME N"
     CostLandUseChange(I)  " COSTS FOR LAND USE CHANGES"
     CostWetland(I) " COSTS FOR WETLANDS"
     CostNFertilizerReduction(I)  " N FERTILIZER REDUCTION COSTS LINEAR"
     PLeakageLandUse(I,L) " P LEAKAGE REDUCTION FROM LAND USE CHANGES"
     PSewageReduction(I)   " SEWAGE P REDUCTION"
     PLoadFertilizer(I)  " LOAD OF FERTILIZER P"
     PSewageDirectLoad(I)  " LOAD OF SEWAGE P EAST"
     PLoadManure(I)  " LOAD OF P MANURE"
     PfromLand(SeaRegions) " Phosphorus land transport"
     CostPSewageReduction(I)  " SEWAGE P REDUCTION COST"
     CostPFertilizerReduction(I)  " COSTS OF RED IN FERTILIZER P"
     totcos(I)   " COUNTRY REDUCTION COST"
     totalCost "total cost of reduction N and P"
;

positive variables
  AmmoniaLiveStockReduction, NFertilizerUse, AmmoniaLandEmission, NOxEmission,
  NOxReduction, NOxDeposition, ArableAirDeposition, AirToLand, AirToSea, NSewageReduction,
  NSewageDirectLoad, NInlandSewageReduction, NRegionToSea, CostManureReduction,
  CostNOxReduction, CostNSewageReduction, NSpreadingTimeChange,
  CostLandUseChange, CostWetland, CostNFertilizerReduction,
  LandUseChanges, NLeakageLandUse, PLeakageLandUse, TotalNLandLoad, NLoadWetland, PLoadWetland ,WetlandRestoration,
  NWetlandReduction, PWetlandReduction, PSewageReduction, PSewageDirectLoad, PInlandSewageReduction,
  PLoadManure, PFertilizerUse, PLoadFertilizer, CostPFertilizerReduction;

# RESTRICTIONS ON VARIABLES

NFertilizerUse.LO(I) =(FertRestriction(I)$(MeasuresControl(I,"Fertilizer") > 0.5)+
                                        1$(MeasuresControl(I,"Fertilizer") < 0.5))*NFERT(I); #changed 2002-01-08
PFertilizerUse.LO(I) =(FertRestriction(I)$(MeasuresControl(I,"Fertilizer") > 0.5)+
                                        1$(MeasuresControl(I,"Fertilizer") < 0.5))*PFERT(I); #changed 2002-01-08
NFertilizerUse.UP(I) = NFERT(I);   #changed 2002-01-08
PFertilizerUse.UP(I) = PFERT(I);   #changed 2002-01-08

AmmoniaLiveStockReduction.UP(I,M) = MeasuresControl(I,"Livestock")*0.5*Livestock(I,M);

WetlandRestoration.UP(I)  = MeasuresControl(I,"Wetland")*WetRestoration(I)/100*
                                                         LandCover(I,"WETLAND");

LandUseChanges.UP(I,L) = MeasuresControl(I,"LandUse")*0.2*LandCover(I,"ARABLE");

NOxReduction.UP(I,"STATION") = MeasuresControl(I,"NOx")*0.6*(NOxCoalEmission(I)+
                                                             NOxOilEmission(I));
NOxReduction.UP(I, "CAR") =    MeasuresControl(I,"NOx")*0.6*NOxGasDieselEmission(I);
NOxReduction.UP(I, "SHIP") =   MeasuresControl(I,"NOx")*0.3*NOxGasDieselEmission(I);

NSewageReduction.UP(I) = MeasuresControl(I,"Sewage")*NSewageCleaningRestriction(I)*DIRN(I);
PSewageReduction.UP(I) =  MeasuresControl(I,"Sewage")*PSewageCleaningRestriction(I)*DIRP(I);

NInlandSewageReduction.UP(I) = MeasuresControl(I,"Sewage")*NSewageCleaningRestriction(I)*INLN(I);
PInlandSewageReduction.UP(I) = MeasuresControl(I,"Sewage")*PSewageCleaningRestriction(I)*INLP(I);

NSpreadingTimeChange.UP(I) = MeasuresControl(I,"SpreadingTime")*ShareManureBareGround(I)*NLiveStock(I);

equations
  CalcAmmoniaEmission(I)   " AMMONIA EmissIONS IN DIFFERENT COUNTRIES"
  CalcNOxEmission(I)   " NOx EmissIONS AFTER ENG RED"
  AmmoniaLoad(I)  " AMMONIA LOAD ON BALTIC COUNTRIES"
  TotalAirLandLoad(I)  " TOTAL AIR LOAD ON LAND"
  NonArableAirLoad(I)   " AIR LOAD ON NON-ARABLE LAND"
  CalcTotalNLandLoad(I)     " TOTAL N LOAD ON LAND"
  TotalAirSeaLoad(I)   " AIR DEPOSITIN ON BALTIC SEA"
  CalcNSewageDirectLoad(I)   " SEWAGE N LOAD ON BALTIC WEST"
  LALER(I,L) " REDUCED LEAKAGE FROM LAND USE CHANGES"

  WELER(I)   " REDUCED N LEAKAGE FROM WETLAND RESTORATION"
  WEPER(I)   " P ABATEMENT BY WETLANDS"

  NWetlandLoad(I)   " N LOAD ON WETLANDS PER SQKM"
  LOAC(I)    " N LOAD PER BALTIC REGION"
  LoadsNitrogen(SeaRegions) " Land thansport"
  NflowRestriction(SeaRegions) " Nitrogen marine transport restriction"
  NdrainageRestriction(SeaRegions) " Drainage basin load restriction"
  CalcNFertCost(I)  " FERTILIZER N COST LINEAR"
  CalcCostManureReduction(I)   " COSTS FOR AMMONIA REDUCTIONS"
  CalcCostNOxReduction(I)   " COSTS FOR NOx REDUCTIONS"
  CalcCostNSewageReduction(I)    " COSTS FOR N SEWGE RED"
  CalcCostLandUseChange(I)   " COSTS FOR LAND USE CHANGES"
  CalcCostWetland(I)  " COSTS FOR WETLANDS"
  CalcPSewageDirectLoad(I)    " DIRECT P DISCHARGES"
  MAPL(I)    " MANURE P LEACHING"
  FERP(I)    " FERTLIZER P LEACHING"
  PALER(I,L) " LAND USE P REDUCTION MEASURES"
  PWetlandLoad(I)   " P LOAD ON WETLANDS"
  TOTPLC(I)  " REGIONAL P LOAD TO THE BALTIC SEA"
  LoadsPhosphorus(SeaRegions) " Land thasport"
  PflowRestriction(SeaRegions) " Nitrogen marine transport restriction"
  PdrainageRestriction(SeaRegions) " Drainage basin load restriction"
  CalcCostPSewageReduction(I)   " SEWAGE TREATMENT PLANT P RED COST"
  CalcPFertCost(I)  " FERTILIZER P RED COST"
  CalcTotcos(i) "total country cost"
  sumCost  " total cost of reduction N and P"
; # end of equations definition

#NITROGEN LOADS AND COSTS EQUATIONS

CalcAmmoniaEmission(I).. AmmoniaLandEmission(I) =E=
   toalag_coeff*(NLiveStock(I)-sum(M,AmmoniaLiveStockReduction(I,M)));

CalcTotalNLandLoad(I).. TotalNLandLoad(I) =E=
   ShareNLeaching(I)*(ArableAirDeposition(I)+NFertilizerUse(I)+
                 ((1-toalag_coeff)*(NLiveStock(I)-sum(M,AmmoniaLiveStockReduction(I,M))))-
                  NSpreadingTimeChange(I));


CalcNOxEmission(I).. NOxEmission(I) =E= TotalNOxEmission(I)-sum(H,NOxReduction(I,H));

TotalAirSeaLoad(I).. AmoniaTransportCoef(I)*AmmoniaLandEmission(I)+
                     NOxTransportCoef(I)*NOxEmission(I) =E= AirToSea(I);

TotalAirLandLoad(I).. (AmmoniaLandEmission(I)*ShareAmmoniaEmission(I))+
                      (NOxEmission(I)*ShareNOxEmission(I)) =E= NOxDeposition(I);
AmmoniaLoad(I).. ArableShare(I)*NOxDeposition(I) =E= ArableAirDeposition(I);
NonArableAirLoad(I).. (1-ArableShare(I))*NOxDeposition(I) =E= AirToLand(I);

LALER(I,L).. NLeakageLandUse(I,L) =E= LeakageReductionCoeff*LandUseChanges(I,L)*
                                      TotalNLandLoad(I)/TotalArableArea(I);

PALER(I,L).. PLeakageLandUse(I,L) =E= LeakageReductionCoeff*LandUseChanges(I,L)*
                     (PLoadManure(I)+PLoadFertilizer(I))/TotalArableArea(I); # was ArableShare(I);

CalcNSewageDirectLoad(I).. DIRN(I)-NSewageReduction(I) =E= NSewageDirectLoad(I);
CalcPSewageDirectLoad(I).. DIRP(I)-PSewageReduction(I) =E= PSewageDirectLoad(I);

NWetlandLoad(I).. NRiverLoadCalibration(I)*(1-DrainageRetention(I,"NITROGEN")/100.0)*
           (INLN(I)-NInlandSewageReduction(I)+TotalNLandLoad(I)+
           AirToLand(I)-sum(L,NLeakageLandUse(I,L)))=E=NLoadWetland(I);

WELER(I).. NWetlandReduction(I) =E=
             WetlandRetention(I)/100.0*WetlandRestoration(I)*0.5*
             (NLoadWetland(I)/(WetRestoration(I)/100*LandCover(I,"WETLAND")));


WEPER(I).. PWetlandReduction(I) =E=
             WetlandRetention(I)/100.0*WetlandRestoration(I)*0.5*
            (PLoadWetland(I)/(WetRestoration(I)/100*LandCover(I,"WETLAND"))); 


LOAC(I).. AirToSea(I)+(1-CoastalRetention(I,"NITROGEN")/100.0)*
                      (NSewageDirectLoad(I)+NLoadWetland(I)-NWetlandReduction(I))=E=NRegionToSea(I);

LoadsNitrogen(SeaRegions)..    sum(I$RegionAreas(SeaRegions,I),NRegionToSea(I))
                               =E= NfromLand(SeaRegions);
                               
NflowRestriction(sea_j).. sum(sea_i,NfromLand(sea_i)*N_transport_coeff(sea_i,sea_j))+
                          N_transport_coeff("KT",sea_j)*atomicWeight("NITROGEN")*
                          skagerFlow("toKT")*skagerConcentration("NITROGEN")/1000.0
                      =L= (1.0-NflowPercentOfReduction(sea_j)/100.0)*Nflow_max(sea_j);
                   
NdrainageRestriction(SeaRegions).. NfromLand(SeaRegions)
                   =L= (1.0-NdrRestPercentOfReduction(SeaRegions)/100.0)*NfromLand_max(SeaRegions);

CalcCostManureReduction(I).. sum(M,PriceLivestockReduction(I,M)*
                          AmmoniaLiveStockReduction(I,M)) =E= CostManureReduction(I);

CalcCostNOxReduction(I).. sum(H,PriceNOxReduction(I,H)*NOxReduction(I,H)) =E= CostNOxReduction(I);

CalcCostNSewageReduction(I).. CostNSewageReduction(I) =E= PriceSewageReduction(I,"NITROGEN")*
                              (NSewageReduction(I)+NInlandSewageReduction(I));

CalcCostPSewageReduction(I).. CostPSewageReduction(I) =E= PriceSewageReduction(I,"PHOSPHORUS")*
                              (PSewageReduction(I)+PInlandSewageReduction(I));

CalcCostLandUseChange(I).. CostLandUseChange(I) =E= sum(L,(LandUseChanges(I,L)*PriceLandUse(I,L)));
CalcCostWetland(I).. CostWetland(I) =E= WetlandRestoration(I)*PriceWetlandRestoration(I);

CalcNFertCost(I).. 15*(INTERN(I)-(FNCOEFF(I)*NFertilizerUse(I))-PriceFertilizer(I,"NITROGEN"))
                   *(NFERT(I)-NFertilizerUse(I))/2 =E= CostNFertilizerReduction(I); #changed 2002-01-08; 2002-01-28 (*15)

MAPL(I).. PLoadManure(I) =E= SharePLeaching(I)*(PLiveStock(I)-
                      sum(M,PNmanureRelation(M)*AmmoniaLiveStockReduction(I,M))-
                      0.2*NSpreadingTimeChange(I));

FERP(I).. PLoadFertilizer(I) =E= SharePLeaching(I)*PFertilizerUse(I);

PWetlandLoad(I).. PRiverLoadCalibration(I)*(1-DrainageRetention(I,"PHOSPHORUS")/100.0)*
           (INLP(I)-PInlandSewageReduction(I)+PLoadManure(I)+PLoadFertilizer(I)-
           sum(L,PLeakageLandUse(I,L)))=E= PLoadWetland(I);

TOTPLC(I).. PRegionToSea(I) =E= (1-CoastalRetention(I,"PHOSPHORUS")/100.0)*
                                (PSewageDirectLoad(I)+PLoadWetland(I)-PWetlandReduction(I));

LoadsPhosphorus(SeaRegions)..  sum(I$RegionAreas(SeaRegions,I),PRegionToSea(I))
                               =E= PfromLand(SeaRegions);

PflowRestriction(sea_j).. sum(sea_i,PfromLand(sea_i)*P_transport_coeff(sea_i,sea_j))+
                          P_transport_coeff("KT",sea_j)*atomicWeight("PHOSPHORUS")*
                          skagerFlow("toKT")*skagerConcentration("PHOSPHORUS")/1000.0
                      =L= (1.0-PflowPercentOfReduction(sea_j)/100.0)*Pflow_max(sea_j);

PdrainageRestriction(SeaRegions).. PfromLand(SeaRegions)
                   =L= (1.0-PdrRestPercentOfReduction(SeaRegions)/100.0)*PfromLand_max(SeaRegions);

CalcPFertCost(I).. 15*(INTERP(I)-(FPCOEFF(I)*PFertilizerUse(I))-PriceFertilizer(I,"PHOSPHORUS"))
                   *(PFERT(I)-PFertilizerUse(I))/2 =E= CostPFertilizerReduction(I); #changed 2002-01-08; 2002-01-28 *15

CalcTotcos(I).. CostManureReduction(I)+CostLandUseChange(I)+CostWetland(I)+
                CostNOxReduction(I)+
                CostNSewageReduction(I)+CostNFertilizerReduction(I)+
                (5.9*NSpreadingTimeChange(I))+             #added 2002-01-08
                CostPSewageReduction(I)+CostPFertilizerReduction(I) =E= totcos(I);

sumCost.. sum(i,totcos(i)) =E= totalCost;

model BAPOAS
  /CalcAmmoniaEmission, CalcNOxEmission, AmmoniaLoad, TotalAirLandLoad,
   NonArableAirLoad, CalcTotalNLandLoad, TotalAirSeaLoad, CalcNSewageDirectLoad, LALER,
   WELER, NWetlandLoad, LOAC, LoadsNitrogen, NflowRestriction, NdrainageRestriction,
   CalcNFertCost, CalcCostManureReduction, CalcCostNOxReduction, CalcCostWetland,
   CalcCostNSewageReduction, CalcCostLandUseChange,
   CalcPSewageDirectLoad, MAPL, FERP, PALER, PWetlandLoad, WEPER, TOTPLC, 
   PflowRestriction, LoadsPhosphorus, PdrainageRestriction,
   CalcCostPSewageReduction, CalcPFertCost, CalcTotcos, sumCost/;


# Calculation of the transport matrices
parameter identity(sea_i,sea_j);
parameter flux(sea_i,sea_j);
parameter total(sea_i);
parameter matrix(sea_i,sea_j);
variable inv_matrix(sea_i,sea_j);
variable dummyObjective;
equation eq(sea_i,sea_j);
eq(sea_i,sea_j).. sum(sea_k, matrix(sea_i,sea_k)*inv_matrix(sea_k,sea_j)) =e= identity(sea_i,sea_j);
equation dummy;
dummy.. dummyObjective =e= 0;
model transportMatrix/eq, dummy/;

parameter NRegionToSea_init(I);
parameter PRegionToSea_init(I);
parameter N_Init_fromLand(SeaRegions); # is needed in Nest for Sink calculation
parameter P_Init_fromLand(SeaRegions); # is needed in Nest for Sink calculation
scalar cycle ;

option lp=conopt; # by default lp is using bdmlp solver which has a problem with Win XP (with Norton Anti Virus soft)


#------------------------------------------------------------------------
# Calculate the calibration coefficients

  solve BAPOAS USING NLP MINIMIZING totalCost;
  NRiverLoadCalibration(I)=NDrainageLoad(I,"RIVER")/NLoadWetland.l(I);
  PRiverLoadCalibration(I)=PDrainageLoad(I,"RIVER")/PLoadWetland.l(I);

# Calculate NfromLand and PfromLand values

  solve BAPOAS USING NLP MINIMIZING totalCost;
  N_Init_fromLand(SeaRegions)=NfromLand.L(SeaRegions); # it is needed in Nest
  P_Init_fromLand(SeaRegions)=PfromLand.L(SeaRegions); # it is needed in Nest
  NRegionToSea_init(i)=NRegionToSea.L(i); # for Nest only
  PRegionToSea_init(i)=PRegionToSea.L(i); # for Nest only
  NfromLand_max(SeaRegions)=NfromLand.L(SeaRegions);
  PfromLand_max(SeaRegions)=PdrainageRestriction.L(SeaRegions);

  identity(sea_i,sea_i)=1;
  flux(sea_i,sea_j)=flow(sea_i,sea_j)*NutrientConcentration(sea_i,"NITROGEN")*atomicWeight("NITROGEN");
  total(sea_j)=sum(sea_i,flux(sea_i,sea_j))+NfromLand.L(sea_j)*1000.0;
  total("KT")=total("KT")+skagerFlow("toKT")*skagerConcentration("NITROGEN")*atomicWeight("NITROGEN");
  matrix(sea_i,sea_j)=identity(sea_i,sea_j)-flux(sea_i,sea_j)/total(sea_i);
  solve transportMatrix using lp minimizing dummyObjective;
  N_transport_coeff(sea_i,sea_j)=inv_matrix.l(sea_i,sea_j);
  
  total(sea_j)=NfromLand.L(sea_j);
  total("KT")=total("KT")+0.001*skagerFlow("toKT")*skagerConcentration("NITROGEN")*atomicWeight("NITROGEN");
  NFlow_max(sea_j)=sum(sea_i,total(sea_i)*N_transport_coeff(sea_i,sea_j));
    
  identity(sea_i,sea_i)=1;
  flux(sea_i,sea_j)=flow(sea_i,sea_j)*NutrientConcentration(sea_i,"PHOSPHORUS")*atomicWeight("PHOSPHORUS");
  total(sea_j)=sum(sea_i,flux(sea_i,sea_j))+PfromLand.L(sea_j)*1000.0;
  total("KT")=total("KT")+skagerFlow("toKT")*skagerConcentration("PHOSPHORUS")*atomicWeight("PHOSPHORUS");
  matrix(sea_i,sea_j)=identity(sea_i,sea_j)-flux(sea_i,sea_j)/total(sea_i);
  solve transportMatrix using lp minimizing dummyObjective;
  P_transport_coeff(sea_i,sea_j)=inv_matrix.l(sea_i,sea_j);
    
  total(sea_j)=PfromLand.L(sea_j);
  total("KT")=total("KT")+0.001*skagerFlow("toKT")*skagerConcentration("PHOSPHORUS")*atomicWeight("PHOSPHORUS");
  PFlow_max(sea_j)=sum(sea_i,total(sea_i)*P_transport_coeff(sea_i,sea_j));
    
  solve BAPOAS USING NLP MINIMIZING totalCost;
#----------------------------------------------------------------------------


parameter CostOfReduction(Countries) "Cost of reduction";
  CostOfReduction(Countries)=sum(I$CountryAreas(Countries,I),totcos.L(I));

parameter CountryNLoads(Countries) "N loads from contries";
  CountryNLoads(Countries)=sum(I$CountryAreas(Countries,I),NRegionToSea.L(I));

parameter CountryNInitLoads(Countries) "N loads from contries";
  CountryNInitLoads(Countries)=sum(I$CountryAreas(Countries,I),NRegionToSea_init(I));

parameter CountryPLoads(Countries) "P loads from contries";
  CountryPLoads(Countries)=sum(I$CountryAreas(Countries,I),PRegionToSea.L(I));

parameter CountryPInitLoads(Countries) "P loads from contries";
  CountryPInitLoads(Countries)=sum(I$CountryAreas(Countries,I),PRegionToSea_init(I));

#Adds
PARAMETER AGRINLOAD(I) "AGRICULTURAL NITROGEN LOAD TO BALTIC SEA PER REGION";
AGRINLOAD(I) = (AmmoniaLandEmission.L(I)*AmoniaTransportCoef(I))+
                (TotalNLandLoad.L(I)-ShareNLeaching(I)*ArableAirDeposition.L(I)*
                NRiverLoadCalibration(I)*(1-DrainageRetention(I,"NITROGEN")));

PARAMETER NOxL(I) "NITROGEN OXIDE FROM ENERGY COMBUSTION TO THE BALTIC SEA";
         NOxL(I) = (NOxEmission.L(I)*NOxTransportCoef(I))+
         (NOxEmission.L(I)*ShareNOxEmission(I)*ShareNLeaching(I)*
          NRiverLoadCalibration(I)*(1-DrainageRetention(I,"NITROGEN")));


#OPTIMAL COSTS OF DIFFERENT MEASURES

PARAMETER AGRCOS(I) "AGRICULTURE N REDUCTION COST";
          AGRCOS(I) = CostManureReduction.L(I)+CostLandUseChange.L(I)+CostNFertilizerReduction.L(I);

PARAMETER PSCOS(I) "POINT SOURCE REDUCTION COST";
         PSCOS(I) = PriceSewageReduction(I,"NITROGEN")*NSewageReduction.L(I);

PARAMETER UPSEWCOS(I) "COSTS OF UPSTREAM SEWAGE ABATMENT MEASURES";
         UPSEWCOS(I) = PriceSewageReduction(I,"NITROGEN")*NInlandSewageReduction.L(I);


# Write results in CSV format
file results /'%gams.user1%'/;
results.pc=5;  # Result will be stored in CSV format
put results;
put BAPOAS.solvestat,BAPOAS.modelstat/;

put 'table' 'Results'/;
  put 'Country';
  put 'Cost (Million EUR/yr)';
  put 'N Reduction (%)';
  put 'P Reduction (%)';
  put /;
put 'Total'; put sum(Countries,CostOfReduction(Countries)):8:2;
             put ((sum(i,NRegionToSea_init(i))-sum(i,NRegionToSea.L(i)))/sum(i,NRegionToSea_init(i))*100.0):8:2;
             put ((sum(i,PRegionToSea_init(i))-sum(i,PRegionToSea.L(i)))/sum(i,PRegionToSea_init(i))*100.0):8:2;
             put /;
loop(Countries, put Countries.TL,
                put CostOfReduction(Countries):8:2,
                put ((CountryNInitLoads(Countries)-CountryNLoads(Countries))/
                     CountryNInitLoads(Countries)*100):8:2,
                put ((CountryPInitLoads(Countries)-CountryPLoads(Countries))/
                     CountryPInitLoads(Countries)*100):8:2,
                put /);
put ';'/;

put 'table' 'ExpertResults'/;
  put 'Country';
  put 'Cost (Million EUR/yr)';
  put 'N Reduction (%)';
  put 'N Loads (thousand ton/yr)';
  put 'P Reduction (%)';
  put 'P Loads (thousand ton/yr)';
  put /;
put 'Total'; put sum(Countries,CostOfReduction(Countries)):8:2;
             put ((sum(i,NRegionToSea_init(i))-sum(i,NRegionToSea.L(i)))/sum(i,NRegionToSea_init(i))*100.0):8:2;
             put sum(Countries,CountryNLoads(Countries)):8:2;
             put ((sum(i,PRegionToSea_init(i))-sum(i,PRegionToSea.L(i)))/sum(i,PRegionToSea_init(i))*100.0):8:2;
             put sum(Countries,CountryPLoads(Countries)):8:2;
             put /;
loop(Countries, put Countries.TL,
                put CostOfReduction(Countries):8:2,
                put ((CountryNInitLoads(Countries)-CountryNLoads(Countries))/
                     CountryNInitLoads(Countries)*100):8:2,
                put CountryNLoads(Countries):8:2;
                put ((CountryPInitLoads(Countries)-CountryPLoads(Countries))/
                     CountryPInitLoads(Countries)*100):8:2,
                put CountryPLoads(Countries):8:2;
                put /);
put ';'/;

put 'table' 'ReductionCost'/;
  put 'Country';
  put 'Total';
  put 'Livestock';
  put 'Land Use';
  put 'Wetland';
  put 'NOx reduction';
  put 'N sewage';
  put 'P sewage';
  put 'N fertilizer';
  put 'P fertilizer';
  put 'Change of N Spreading Time';
  put /;
loop(Countries, put Countries.TL,
                put sum(I$CountryAreas(Countries,I),totcos.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostManureReduction.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostLandUseChange.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostWetland.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostNOxReduction.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostNSewageReduction.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostPSewageReduction.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostNFertilizerReduction.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),CostPFertilizerReduction.L(I)):8:2,
                put sum(I$CountryAreas(Countries,I),5.9*NSpreadingTimeChange.L(I)):8:2,
                put /);
put ';'/;

put 'table' 'NReduction'/;
put 'Area'; put 'Value'; put /;
loop(I, put I.TL, put (NRegionToSea_init(I)-NRegionToSea.L(I)):8:2; put /);
put ';'/;

put 'table' 'PReduction'/;
put 'Area'; put 'Value'; put /;
loop(I, put I.TL, put (PRegionToSea_init(I)-PRegionToSea.L(I)):8:2; put /);
put ';'/;

put 'table' 'InitLoadsFromLand'/;
  put 'Region';
  put 'N Load';
  put 'P Load';
  put /;
loop(SeaRegions, put SeaRegions.TL,
                put N_Init_fromLand(SeaRegions):8:2,
                put P_Init_fromLand(SeaRegions):8:2,
                put /);
put ';'/;

put 'table' 'LoadsFromLand'/;
  put 'Region';
  put 'N Load';
  put 'P Load';
  put 'AirToLand';
  put 'AirToSea';
  put /;
loop(SeaRegions, put SeaRegions.TL,
                put NfromLand.L(SeaRegions):8:2,
                put PfromLand.L(SeaRegions):8:2,
                put sum(I$RegionAreas(SeaRegions,I),AirToLand.L(I)):8:2,
                put sum(I$RegionAreas(SeaRegions,I),AirToSea.L(I)):8:2,
                put /);
put ';'/;

put 'table' 'LoadsTotal'/;
  put 'Region';
  put 'N Load total';
  put 'P Load total';
  put /;
loop(SeaRegions, put SeaRegions.TL,
                put NFlow_max(SeaRegions):8:2,
                put PFlow_max(SeaRegions):8:2,
                put /);
put ';'/;

putclose results;

#*** Templates *******************************
$ontext
put 'table' 'AmmoniaLiveStockReduction'/;
put 'Area'; loop(M, put M.TL); put /; # table's header
loop(I, put I.TL,
  loop(M, put AmmoniaLiveStockReduction.L(I,M):8:4); put /);
put ';'/;

put 'table' 'NfromLand'/;
put 'Area'; put 'Value'; put /;
loop(SeaRegions, put SeaRegions.TL, put NfromLand.L(SeaRegions):8:4; put /);
put ';'/;
$offtext
#*****************************************************
